@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2015 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2017 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -21,7 +21,6 @@
 
 import sys
 
-from glances.compat import NoOptionError, NoSectionError
 from glances.logger import logger
 from glances.exports.glances_export import GlancesExport
 
@@ -43,54 +42,27 @@ class Export(GlancesExport):
         """Init the InfluxDB export IF."""
         super(Export, self).__init__(config=config, args=args)
 
-        # Load the InfluxDB configuration file
-        self.host = None
-        self.port = None
+        # Mandatories configuration keys (additional to host and port)
         self.user = None
         self.password = None
         self.db = None
+
+        # Optionals configuration keys
         self.prefix = None
         self.tags = None
-        self.export_enable = self.load_conf()
+
+        # Load the InfluxDB configuration file
+        self.export_enable = self.load_conf('influxdb',
+                                            mandatories=['host', 'port',
+                                                         'user', 'password',
+                                                         'db'],
+                                            options=['prefix', 'tags'])
         if not self.export_enable:
             sys.exit(2)
 
         # Init the InfluxDB client
         self.client = self.init()
 
-    def load_conf(self, section="influxdb"):
-        """Load the InfluxDb configuration in the Glances configuration file."""
-        if self.config is None:
-            return False
-        try:
-            self.host = self.config.get_value(section, 'host')
-            self.port = self.config.get_value(section, 'port')
-            self.user = self.config.get_value(section, 'user')
-            self.password = self.config.get_value(section, 'password')
-            self.db = self.config.get_value(section, 'db')
-        except NoSectionError:
-            logger.critical("No InfluxDB configuration found")
-            return False
-        except NoOptionError as e:
-            logger.critical("Error in the InfluxDB configuration (%s)" % e)
-            return False
-        else:
-            logger.debug("Load InfluxDB from the Glances configuration file")
-
-        # Prefix is optional
-        try:
-            self.prefix = self.config.get_value(section, 'prefix')
-        except NoOptionError:
-            pass
-
-        # Tags are optional, comma separated key:value pairs.
-        try:
-            self.tags = self.config.get_value(section, 'tags')
-        except NoOptionError:
-            pass
-
-        return True
-
     def init(self):
         """Init the connection to the InfluxDB server."""
         if not self.export_enable:
@@ -120,7 +92,7 @@ class Export(GlancesExport):
 
         if self.db in get_all_db:
             logger.info(
-                "Stats will be exported to InfluxDB server: {0}".format(db._baseurl))
+                "Stats will be exported to InfluxDB server: {}".format(db._baseurl))
         else:
             logger.critical("InfluxDB database '%s' did not exist. Please create it" % self.db)
             sys.exit(2)
@@ -129,7 +101,7 @@ class Export(GlancesExport):
 
     def export(self, name, columns, points):
         """Write the points to the InfluxDB server."""
-        logger.debug("Export {0} stats to InfluxDB".format(name))
+        logger.debug("Export {} stats to InfluxDB".format(name))
         # Manage prefix
         if self.prefix is not None:
             name = self.prefix + '.' + name
@@ -143,7 +115,7 @@ class Export(GlancesExport):
                 try:
                     points[i] = float(points[i])
                 except (TypeError, ValueError) as e:
-                    logger.debug("InfluxDB error diring stat convertion %s=%s (%s)" % (columns[i], points[i], e))
+                    logger.debug("InfluxDB error during stat convertion %s=%s (%s)" % (columns[i], points[i], e))
 
             data = [{'measurement': name,
                      'tags': self.parse_tags(self.tags),
@@ -152,4 +124,4 @@ class Export(GlancesExport):
         try:
             self.client.write_points(data)
         except Exception as e:
-            logger.error("Cannot export {0} stats to InfluxDB ({1})".format(name, e))
+            logger.error("Cannot export {} stats to InfluxDB ({})".format(name, e))
