@@ -61,6 +61,9 @@ class Export(GlancesExport):
         """Init the connection to the Statsd server."""
         if not self.export_enable:
             return None
+        logger.info(
+            "Stats will be exported to StatsD server: {}:{}".format(self.host,
+                                                                    self.port))
         return StatsClient(self.host,
                            int(self.port),
                            prefix=prefix)
