@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2015 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2017 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -24,7 +24,9 @@ import os
 import sys
 import tempfile
 from io import open
+import webbrowser
 
+from glances.timer import Timer
 from glances.logger import logger
 
 try:
@@ -38,7 +40,10 @@ class GlancesBottle(object):
 
     """This class manages the Bottle Web server."""
 
-    def __init__(self, args=None):
+    def __init__(self, config=None, args=None):
+        # Init config
+        self.config = config
+
         # Init args
         self.args = args
 
@@ -46,6 +51,14 @@ class GlancesBottle(object):
         # Will be updated within Bottle route
         self.stats = None
 
+        # cached_time is the minimum time interval between stats updates
+        # i.e. HTTP/Restful calls will not retrieve updated info until the time
+        # since last update is passed (will retrieve old cached info instead)
+        self.timer = Timer(0)
+
+        # Load configuration file
+        self.load_config(config)
+
         # Init Bottle
         self._app = Bottle()
         # Enable CORS (issue #479)
@@ -59,6 +72,20 @@ class GlancesBottle(object):
         # Path where the statics files are stored
         self.STATIC_PATH = os.path.join(os.path.dirname(os.path.realpath(__file__)), 'static/public')
 
+    def load_config(self, config):
+        """Load the outputs section of the configuration file."""
+        # Limit the number of processes to display in the WebUI
+        if config is not None and config.has_section('outputs'):
+            logger.debug('Read number of processes to display in the WebUI')
+            n = config.get_value('outputs', 'max_processes_display', default=None)
+            logger.debug('Number of processes to display in the WebUI: {}'.format(n))
+
+    def __update__(self):
+        # Never update more than 1 time per cached_time
+        if self.timer.finished():
+            self.stats.update()
+            self.timer = Timer(self.args.cached_time)
+
     def app(self):
         return self._app()
 
@@ -77,6 +104,8 @@ class GlancesBottle(object):
         self._app.route('/<refresh_time:int>', method=["GET"], callback=self._index)
 
         # REST API
+        self._app.route('/api/2/config', method="GET", callback=self._api_config)
+        self._app.route('/api/2/config/<item>', method="GET", callback=self._api_config_item)
         self._app.route('/api/2/args', method="GET", callback=self._api_args)
         self._app.route('/api/2/args/<item>', method="GET", callback=self._api_args_item)
         self._app.route('/api/2/help', method="GET", callback=self._api_help)
@@ -105,9 +134,17 @@ class GlancesBottle(object):
         self.plugins_list = self.stats.getAllPlugins()
 
         # Bind the Bottle TCP address/port
-        bindmsg = 'Glances web server started on http://{}:{}/'.format(self.args.bind_address, self.args.port)
+        bindurl = 'http://{}:{}/'.format(self.args.bind_address,
+                                         self.args.port)
+        bindmsg = 'Glances web server started on {}'.format(bindurl)
         logger.info(bindmsg)
         print(bindmsg)
+        if self.args.open_web_browser:
+            # Implementation of the issue #946
+            # Try to open the Glances Web UI in the default Web browser if:
+            # 1) --open-web-browser option is used
+            # 2) Glances standalone mode is running on Windows OS
+            webbrowser.open(bindurl, new=2, autoraise=1)
         self._app.run(host=self.args.bind_address, port=self.args.port, quiet=not self.args.debug)
 
     def end(self):
@@ -117,7 +154,7 @@ class GlancesBottle(object):
     def _index(self, refresh_time=None):
         """Bottle callback for index.html (/) file."""
         # Update the stat
-        self.stats.update()
+        self.__update__()
 
         # Display
         return static_file("index.html", root=self.STATIC_PATH)
@@ -170,7 +207,7 @@ class GlancesBottle(object):
         response.content_type = 'application/json'
 
         # Update the stat
-        self.stats.update()
+        self.__update__()
 
         try:
             plist = json.dumps(self.plugins_list)
@@ -197,7 +234,7 @@ class GlancesBottle(object):
                 logger.debug("Debug file (%s) not found" % fname)
 
         # Update the stat
-        self.stats.update()
+        self.__update__()
 
         try:
             # Get the JSON value of the stat ID
@@ -254,7 +291,7 @@ class GlancesBottle(object):
             abort(400, "Unknown plugin %s (available plugins: %s)" % (plugin, self.plugins_list))
 
         # Update the stat
-        self.stats.update()
+        self.__update__()
 
         try:
             # Get the JSON value of the stat ID
@@ -278,7 +315,7 @@ class GlancesBottle(object):
             abort(400, "Unknown plugin %s (available plugins: %s)" % (plugin, self.plugins_list))
 
         # Update the stat
-        self.stats.update()
+        self.__update__()
 
         try:
             # Get the JSON value of the stat ID
@@ -301,7 +338,7 @@ class GlancesBottle(object):
             abort(400, "Unknown plugin %s (available plugins: %s)" % (plugin, self.plugins_list))
 
         # Update the stat
-        # self.stats.update()
+        # self.__update__()
 
         try:
             # Get the JSON value of the stat limits
@@ -324,7 +361,7 @@ class GlancesBottle(object):
             abort(400, "Unknown plugin %s (available plugins: %s)" % (plugin, self.plugins_list))
 
         # Update the stat
-        # self.stats.update()
+        # self.__update__()
 
         try:
             # Get the JSON value of the stat views
@@ -341,7 +378,7 @@ class GlancesBottle(object):
             abort(400, "Unknown plugin %s (available plugins: %s)" % (plugin, self.plugins_list))
 
         # Update the stat
-        self.stats.update()
+        self.__update__()
 
         if value is None:
             if history:
@@ -395,6 +432,43 @@ class GlancesBottle(object):
         """
         return self._api_itemvalue(plugin, item, value)
 
+    def _api_config(self):
+        """Glances API RESTFul implementation.
+
+        Return the JSON representation of the Glances configuration file
+        HTTP/200 if OK
+        HTTP/404 if others error
+        """
+        response.content_type = 'application/json'
+
+        try:
+            # Get the JSON value of the config' dict
+            args_json = json.dumps(self.config.as_dict())
+        except Exception as e:
+            abort(404, "Cannot get config (%s)" % str(e))
+        return args_json
+
+    def _api_config_item(self, item):
+        """Glances API RESTFul implementation.
+
+        Return the JSON representation of the Glances configuration item
+        HTTP/200 if OK
+        HTTP/400 if item is not found
+        HTTP/404 if others error
+        """
+        response.content_type = 'application/json'
+
+        config_dict = self.config.as_dict()
+        if item not in config_dict:
+            abort(400, "Unknown configuration item %s" % item)
+
+        try:
+            # Get the JSON value of the config' dict
+            args_json = json.dumps(config_dict[item])
+        except Exception as e:
+            abort(404, "Cannot get config item (%s)" % str(e))
+        return args_json
+
     def _api_args(self):
         """Glances API RESTFul implementation.
 
@@ -424,7 +498,7 @@ class GlancesBottle(object):
         response.content_type = 'application/json'
 
         if item not in self.args:
-            abort(400, "Unknown item %s" % item)
+            abort(400, "Unknown argument item %s" % item)
 
         try:
             # Get the JSON value of the args' dict
