@@ -54,11 +54,12 @@ class _GlancesCurses(object):
         '3': {'switch': 'disable_quicklook'},
         '6': {'switch': 'meangpu'},
         '/': {'switch': 'process_short_name'},
-        'd': {'switch': 'disable_diskio'},
         'A': {'switch': 'disable_amps'},
         'b': {'switch': 'byte'},
         'B': {'switch': 'diskio_iops'},
+        'C': {'switch': 'disable_cloud'},
         'D': {'switch': 'disable_docker'},
+        'd': {'switch': 'disable_diskio'},
         'F': {'switch': 'fs_free_space'},
         'G': {'switch': 'disable_gpu'},
         'h': {'switch': 'help_tag'},
@@ -514,9 +515,11 @@ class _GlancesCurses(object):
         __stat_display = self.__get_stat_display(stats, plugin_max_width)
 
         # Adapt number of processes to the available space
-        max_processes_displayed = self.screen.getmaxyx()[0] - 11 - \
-            self.get_stats_display_height(__stat_display["alert"]) - \
+        max_processes_displayed = (
+            self.screen.getmaxyx()[0] - 11 -
+            self.get_stats_display_height(__stat_display["alert"]) -
             self.get_stats_display_height(__stat_display["docker"])
+        )
         try:
             if self.args.enable_process_extended and not self.args.process_tree:
                 max_processes_displayed -= 4
@@ -545,6 +548,7 @@ class _GlancesCurses(object):
 
         # =====================================
         # Display first line (system+ip+uptime)
+        # Optionnaly: Cloud on second line
         # =====================================
         self.__display_firstline(__stat_display)
 
@@ -616,10 +620,10 @@ class _GlancesCurses(object):
         # Space between column
         self.space_between_column = 0
         self.new_line()
-        l_uptime = self.get_stats_display_width(stat_display["system"]) \
-            + self.space_between_column \
-            + self.get_stats_display_width(stat_display["ip"]) + 3 \
-            + self.get_stats_display_width(stat_display["uptime"])
+        l_uptime = (self.get_stats_display_width(stat_display["system"]) +
+                    self.space_between_column +
+                    self.get_stats_display_width(stat_display["ip"]) + 3 +
+                    self.get_stats_display_width(stat_display["uptime"]))
         self.display_plugin(
             stat_display["system"],
             display_optional=(self.screen.getmaxyx()[1] >= l_uptime))
@@ -628,7 +632,11 @@ class _GlancesCurses(object):
         # Space between column
         self.space_between_column = 3
         self.new_column()
-        self.display_plugin(stat_display["uptime"])
+        self.display_plugin(stat_display["uptime"],
+                            add_space=self.get_stats_display_width(stat_display["cloud"]) == 0)
+        self.init_column()
+        self.new_line()
+        self.display_plugin(stat_display["cloud"])
 
     def __display_secondline(self, stat_display, stats):
         """Display the second line in the Curses interface.
@@ -716,8 +724,8 @@ class _GlancesCurses(object):
         if not self.args.disable_left_sidebar:
             for s in ['network', 'wifi', 'ports', 'diskio', 'fs', 'irq',
                       'folders', 'raid', 'sensors', 'now']:
-                if (hasattr(self.args, 'enable_' + s) or
-                    hasattr(self.args, 'disable_' + s)) and s in stat_display:
+                if ((hasattr(self.args, 'enable_' + s) or
+                     hasattr(self.args, 'disable_' + s)) and s in stat_display):
                     self.new_line()
                     self.display_plugin(stat_display[s])
 
@@ -829,7 +837,8 @@ class _GlancesCurses(object):
     def display_plugin(self, plugin_stats,
                        display_optional=True,
                        display_additional=True,
-                       max_y=65535):
+                       max_y=65535,
+                       add_space=True):
         """Display the plugin_stats on the screen.
 
         If display_optional=True display the optional stats
@@ -913,6 +922,10 @@ class _GlancesCurses(object):
             self.next_column, x_max + self.space_between_column)
         self.next_line = max(self.next_line, y + self.space_between_line)
 
+        if not add_space and self.next_line > 0:
+            # Do not have empty line after
+            self.next_line -= 1
+
     def erase(self):
         """Erase the content of the screen."""
         self.term_window.erase()
