@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2015 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2017 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -86,6 +86,19 @@ class GlancesPlugin(object):
         """Return the key of the list."""
         return None
 
+    def is_enable(self):
+        """Return true if plugin is enabled"""
+        try:
+            d = getattr(self.args, 'disable_' + self.plugin_name)
+        except AttributeError:
+            return True
+        else:
+            return d is False
+
+    def is_disable(self):
+        """Return true if plugin is disabled"""
+        return not self.is_enable()
+
     def _json_dumps(self, d):
         """Return the object 'd' in a JSON format
         Manage the issue #815 for Windows OS"""
@@ -101,18 +114,24 @@ class GlancesPlugin(object):
         """Init the stats history (dict of GlancesAttribute)."""
         if self._history_enable():
             init_list = [a['name'] for a in self.get_items_history_list()]
-            logger.debug("Stats history activated for plugin {0} (items: {1})".format(self.plugin_name, init_list))
+            logger.debug("Stats history activated for plugin {} (items: {})".format(self.plugin_name, init_list))
         return GlancesHistory()
 
     def reset_stats_history(self):
         """Reset the stats history (dict of GlancesAttribute)."""
         if self._history_enable():
             reset_list = [a['name'] for a in self.get_items_history_list()]
-            logger.debug("Reset history for plugin {0} (items: {1})".format(self.plugin_name, reset_list))
+            logger.debug("Reset history for plugin {} (items: {})".format(self.plugin_name, reset_list))
             self.stats_history.reset()
 
-    def update_stats_history(self, item_name=''):
+    def update_stats_history(self):
         """Update stats history."""
+        # If the plugin data is a dict, the dict's key should be used
+        if self.get_key() is None:
+            item_name = ''
+        else:
+            item_name = self.get_key()
+        # Build the history
         if self.stats and self._history_enable():
             for i in self.get_items_history_list():
                 if isinstance(self.stats, list):
@@ -183,7 +202,7 @@ class GlancesPlugin(object):
             try:
                 return self._json_dumps({item: s[item]})
             except KeyError as e:
-                logger.error("Cannot get item history {0} ({1})".format(item, e))
+                logger.error("Cannot get item history {} ({})".format(item, e))
                 return None
         elif isinstance(s, list):
             try:
@@ -191,7 +210,7 @@ class GlancesPlugin(object):
                 # http://stackoverflow.com/questions/4573875/python-get-index-of-dictionary-item-in-list
                 return self._json_dumps({item: map(itemgetter(item), s)})
             except (KeyError, ValueError) as e:
-                logger.error("Cannot get item history {0} ({1})".format(item, e))
+                logger.error("Cannot get item history {} ({})".format(item, e))
                 return None
         else:
             return None
@@ -393,7 +412,10 @@ class GlancesPlugin(object):
             if option is None:
                 return item_views[key]
             else:
-                return item_views[key][option]
+                if option in item_views[key]:
+                    return item_views[key][option]
+                else:
+                    return 'DEFAULT'
 
     def load_limits(self, config):
         """Load limits from the configuration file, if it exists."""
@@ -407,7 +429,7 @@ class GlancesPlugin(object):
         # Read the global section
         if config.has_section('global'):
             self._limits['history_size'] = config.get_float_value('global', 'history_size', default=28800)
-            logger.debug("Load configuration key: {0} = {1}".format('history_size', self._limits['history_size']))
+            logger.debug("Load configuration key: {} = {}".format('history_size', self._limits['history_size']))
 
         # Read the plugin specific section
         if config.has_section(self.plugin_name):
@@ -432,7 +454,22 @@ class GlancesPlugin(object):
         """Set the limits to input_limits."""
         self._limits = input_limits
 
-    def get_alert(self, current=0, minimum=0, maximum=100, header="", log=False):
+    def get_stats_action(self):
+        """Return stats for the action
+        By default return all the stats.
+        Can be overwrite by plugins implementation.
+        For example, Docker will return self.stats['containers']"""
+        return self.stats
+
+    def get_alert(self,
+                  current=0,
+                  minimum=0,
+                  maximum=100,
+                  highlight_zero=True,
+                  is_max=False,
+                  header="",
+                  action_key=None,
+                  log=False):
         """Return the alert status relative to a current value.
 
         Use this function for minor stats.
@@ -442,13 +479,22 @@ class GlancesPlugin(object):
         If current > WARNING of max then alert = WARNING
         If current > CRITICAL of max then alert = CRITICAL
 
+        If highlight=True than 0.0 is highlighted
+
         If defined 'header' is added between the plugin name and the status.
         Only useful for stats with several alert status.
 
+        If defined, 'action_key' define the key for the actions.
+        By default, the action_key is equal to the header.
+
         If log=True than add log if necessary
         elif log=False than do not log
-        elig log=None than apply the config given in the conf file
+        elif log=None than apply the config given in the conf file
         """
+        # Manage 0 (0.0) value if highlight_zero is not True
+        if not highlight_zero and current == 0:
+            return 'DEFAULT'
+
         # Compute the %
         try:
             value = (current * 100) / maximum
@@ -464,13 +510,14 @@ class GlancesPlugin(object):
             stat_name = self.plugin_name + '_' + header
 
         # Manage limits
-        ret = 'OK'
+        # If is_max is set then display the value in MAX
+        ret = 'MAX' if is_max else 'OK'
         try:
-            if value > self.__get_limit('critical', stat_name=stat_name):
+            if value >= self.get_limit('critical', stat_name=stat_name):
                 ret = 'CRITICAL'
-            elif value > self.__get_limit('warning', stat_name=stat_name):
+            elif value >= self.get_limit('warning', stat_name=stat_name):
                 ret = 'WARNING'
-            elif value > self.__get_limit('careful', stat_name=stat_name):
+            elif value >= self.get_limit('careful', stat_name=stat_name):
                 ret = 'CAREFUL'
             elif current < minimum:
                 ret = 'CAREFUL'
@@ -479,7 +526,7 @@ class GlancesPlugin(object):
 
         # Manage log
         log_str = ""
-        if self.__get_limit_log(stat_name=stat_name, default_action=log):
+        if self.get_limit_log(stat_name=stat_name, default_action=log):
             # Add _LOG to the return string
             # So stats will be highlited with a specific color
             log_str = "_LOG"
@@ -487,38 +534,61 @@ class GlancesPlugin(object):
             glances_logs.add(ret, stat_name.upper(), value)
 
         # Manage action
-        # Here is a command line for the current trigger ?
-        try:
-            command = self.__get_limit_action(ret.lower(), stat_name=stat_name)
-        except KeyError:
-            # Reset the trigger
-            self.actions.set(stat_name, ret.lower())
-        else:
-            # A command line is available for the current alert, run it
-            # Build the {{mustache}} dictionnary
-            if isinstance(self.stats, list):
-                # If the stats are stored in a list of dict (fs plugin for exemple)
-                # Return the dict for the current header
-                mustache_dict = {}
-                for item in self.stats:
-                    if item[self.get_key()] == header:
-                        mustache_dict = item
-                        break
-            else:
-                # Use the stats dict
-                mustache_dict = self.stats
-            # Run the action
-            self.actions.run(
-                stat_name, ret.lower(), command, mustache_dict=mustache_dict)
+        self.manage_action(stat_name, ret.lower(), header, action_key)
 
         # Default is ok
         return ret + log_str
 
-    def get_alert_log(self, current=0, minimum=0, maximum=100, header=""):
-        """Get the alert log."""
-        return self.get_alert(current, minimum, maximum, header, log=True)
+    def manage_action(self,
+                      stat_name,
+                      trigger,
+                      header,
+                      action_key):
+        """Manage the action for the current stat"""
+        # Here is a command line for the current trigger ?
+        try:
+            command = self.get_limit_action(trigger, stat_name=stat_name)
+        except KeyError:
+            # Reset the trigger
+            self.actions.set(stat_name, trigger)
+        else:
+            # Define the action key for the stats dict
+            # If not define, then it sets to header
+            if action_key is None:
+                action_key = header
 
-    def __get_limit(self, criticity, stat_name=""):
+            # A command line is available for the current alert
+            # 1) Build the {{mustache}} dictionnary
+            if isinstance(self.get_stats_action(), list):
+                # If the stats are stored in a list of dict (fs plugin for exemple)
+                # Return the dict for the current header
+                mustache_dict = {}
+                for item in self.get_stats_action():
+                    if item[self.get_key()] == action_key:
+                        mustache_dict = item
+                        break
+            else:
+                # Use the stats dict
+                mustache_dict = self.get_stats_action()
+            # 2) Run the action
+            self.actions.run(
+                stat_name, trigger, command, mustache_dict=mustache_dict)
+
+    def get_alert_log(self,
+                      current=0,
+                      minimum=0,
+                      maximum=100,
+                      header="",
+                      action_key=None):
+        """Get the alert log."""
+        return self.get_alert(current=current,
+                              minimum=minimum,
+                              maximum=maximum,
+                              header=header,
+                              action_key=action_key,
+                              log=True)
+
+    def get_limit(self, criticity, stat_name=""):
         """Return the limit value for the alert."""
         # Get the limit for stat + header
         # Exemple: network_wlan0_rx_careful
@@ -534,7 +604,7 @@ class GlancesPlugin(object):
         # Return the limit
         return limit
 
-    def __get_limit_action(self, criticity, stat_name=""):
+    def get_limit_action(self, criticity, stat_name=""):
         """Return the action for the alert."""
         # Get the action for stat + header
         # Exemple: network_wlan0_rx_careful_action
@@ -548,7 +618,7 @@ class GlancesPlugin(object):
         # Return the action list
         return ret
 
-    def __get_limit_log(self, stat_name, default_action=False):
+    def get_limit_log(self, stat_name, default_action=False):
         """Return the log tag for the alert."""
         # Get the log tag for stat + header
         # Exemple: network_wlan0_rx_log
@@ -728,6 +798,16 @@ class GlancesPlugin(object):
                     value, decimal=decimal_precision, symbol=symbol)
         return '{!s}'.format(number)
 
+    def _check_decorator(fct):
+        """Check if the plugin is enabled."""
+        def wrapper(self, *args, **kw):
+            if self.is_enable():
+                ret = fct(self, *args, **kw)
+            else:
+                ret = self.stats
+            return ret
+        return wrapper
+
     def _log_result_decorator(fct):
         """Log (DEBUG) the result of the function fct."""
         def wrapper(*args, **kw):
@@ -740,4 +820,5 @@ class GlancesPlugin(object):
         return wrapper
 
     # Mandatory to call the decorator in childs' classes
+    _check_decorator = staticmethod(_check_decorator)
     _log_result_decorator = staticmethod(_log_result_decorator)
