@@ -100,9 +100,9 @@ class Plugin(GlancesPlugin):
             return 'CAREFUL'
         elif port['status'] == 0:
             return 'CRITICAL'
-        elif isinstance(port['status'], (float, int)) and \
-                port['rtt_warning'] is not None and \
-                port['status'] > port['rtt_warning']:
+        elif (isinstance(port['status'], (float, int)) and
+              port['rtt_warning'] is not None and
+              port['status'] > port['rtt_warning']):
             return 'WARNING'
 
         return 'OK'
@@ -118,7 +118,9 @@ class Plugin(GlancesPlugin):
 
         # Build the string message
         for p in self.stats:
-            if p['status'] is None:
+            if p['host'] is None:
+                status = 'None'
+            elif p['status'] is None:
                 status = 'Scanning'
             elif isinstance(p['status'], bool_type) and p['status'] is True:
                 status = 'Open'
