@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2016 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2017 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -51,7 +51,7 @@ class GlancesStatsClient(GlancesStats):
             # for example, the file glances_xxx.py
             # generate self._plugins_list["xxx"] = ...
             logger.debug("Server uses {} plugin".format(item))
-            self._plugins[item] = plugin.Plugin()
+            self._plugins[item] = plugin.Plugin(args=self.args)
         # Restoring system path
         sys.path = sys_path
 
